@@ -1,8 +1,7 @@
 from markupsafe import Markup
-import json
 
 
 def inertia(page_data, app_id="app"):
     """Inertia view helper to render a div with page data required by client-side
     Inertia.js adapter."""
-    return Markup(f"<div id='{app_id}' data-page='{json.dumps(page_data)}'></div>")
+    return Markup(f'<div id="{app_id}" data-page="{page_data}"></div>')
