@@ -23,14 +23,14 @@ class TestInertiaViewHelper(TestCase):
         page_data = {"page": "test"}
         data = inertia(page_data)
         self.assertIsInstance(data, Markup)
-        self.assertEqual("<div id='app' data-page='{\"page\": \"test\"}'></div>", str(data))
+        self.assertEqual("<div id=\"app\" data-page=\"{'page': 'test'}\"></div>", str(data))
 
     def test_helper_renders_page_data_correctly_inside_template(self):
         response = self.get("/root-with-helper")
         response.assertContains(
-            "<div id='app' data-page='\"{&quot;component&quot;: &quot;Index&quot;, &quot;props&quot;: {&quot;auth&quot;: {&quot;user&quot;: &quot;&quot;}, &quot;errors&quot;: {}}, &quot;url&quot;: &quot;/root-with-helper&quot;, &quot;version&quot;: &quot;123&quot;}\"'></div>"  # noqa: E501
+            '<div id="app" data-page="{&quot;component&quot;: &quot;Index&quot;, &quot;props&quot;: {&quot;auth&quot;: {&quot;user&quot;: &quot;&quot;}, &quot;errors&quot;: {}}, &quot;url&quot;: &quot;/root-with-helper&quot;, &quot;version&quot;: &quot;123&quot;}"></div>'  # noqa: E501
         )
 
     def test_can_customize_app_id_through_helper(self):
         response = self.get("/custom-id")
-        response.assertContains("<div id='my_app'")
+        response.assertContains('<div id="my_app"')
